==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/utility/units_and_measurements/measurements/_1703.py <==
"""HeatTransfer"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_HEAT_TRANSFER = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "HeatTransfer"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="HeatTransfer")
    CastSelf = TypeVar("CastSelf", bound="HeatTransfer._Cast_HeatTransfer")


__docformat__ = "restructuredtext en"
__all__ = ("HeatTransfer",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HeatTransfer:
    """Special nested class for casting HeatTransfer to subclasses."""

    __parent__: "HeatTransfer"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def heat_transfer(self: "CastSelf") -> "HeatTransfer":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class HeatTransfer(_1655.MeasurementBase):
    """HeatTransfer

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HEAT_TRANSFER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_HeatTransfer":
        """Cast to another type.

        Returns:
            _Cast_HeatTransfer
        """
        return _Cast_HeatTransfer(self)

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/utility/units_and_measurements/measurements/_1703.py <==
"""Gradient"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_GRADIENT = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Gradient"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Gradient")
    CastSelf = TypeVar("CastSelf", bound="Gradient._Cast_Gradient")


__docformat__ = "restructuredtext en"
__all__ = ("Gradient",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Gradient:
    """Special nested class for casting Gradient to subclasses."""

    __parent__: "Gradient"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def gradient(self: "CastSelf") -> "Gradient":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Gradient(_1657.MeasurementBase):
    """Gradient

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GRADIENT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Gradient":
        """Cast to another type.

        Returns:
            _Cast_Gradient
        """
        return _Cast_Gradient(self)
